\name{Animal}
\alias{Animal}
\non_function{}
\title{Animal breeding experiment}
\description{
    The \code{Animal} data frame has 20 rows and 3 columns giving the
    average daily weight gains for animals with different genetic
    backgrounds.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Sire}{
	    a factor denoting the sire. (5 levels)
	}
	\item{Dam}{
	    a factor denoting the dam. (2 levels)
	}
	\item{AvgDailyGain}{
	    a numeric vector of average daily weight gains
	}
    }
}\details{
    This appears to be a constructed data set.
}
\source{
    Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
    R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
    (Data Set 6.4).
}
\examples{
data(Animal)
str(Animal)
}
\keyword{datasets}

\eof
\name{AvgDailyGain}
\alias{AvgDailyGain}
\non_function{}
\title{Average daily weight gain of steers on different diets}
\description{
    The \code{AvgDailyGain} data frame has 32 rows and 6 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Id}{
	    the animal number
	}
	\item{Block}{
	    an ordered factor indicating the barn in which the steer was housed.
	}
	\item{Treatment}{
	    an ordered factor with levels
	    \code{0} < \code{10} < \code{20} < \code{30}
	    indicating the amount of medicated feed additive added to
	    the base ration.
	}
	\item{adg}{
	    a numeric vector of average daily weight gains over a period
	    of 160 days.
	}
	\item{InitWt}{
	    a numeric vector giving the initial weight of the animal
	}
	\item{Trt}{
	    the \code{Treatment} as a numeric variable
	}
    }
}
\source{
    Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
    R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
    (Data Set 5.3).
}
\examples{
data(AvgDailyGain)
options(
  contrasts = c(unordered = "contr.SAS", ordered = "contr.poly"))
## plot of adg versus Treatment by Block
coplot(adg ~ as.numeric(Treatment) | Block, data = AvgDailyGain,
       show = FALSE)
fm1Adg <- lme( adg ~ InitWt * Treatment - 1, 
      data = AvgDailyGain, random = ~ 1 | Block)
summary( fm1Adg ) # compare with output 5.1, p. 178
VarCorr( fm1Adg ) # show the variance component estimates
anova( fm1Adg )   # checking significance of terms
fm2Adg <- update( fm1Adg, adg ~ InitWt + Treatment )  # common slope model
summary( fm2Adg )
VarCorr( fm2Adg )
anova( fm2Adg )
summary( update( fm1Adg, adg ~ InitWt + Treatment - 1 ) )
}
\keyword{datasets}

\eof
\name{BIB}
\alias{BIB}
\non_function{}
\title{Data from a balanced incomplete block design}
\description{
    The \code{BIB} data frame has 24 rows and 5 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Block}{
	    an ordered factor with levels
	    \code{1} < \code{2} < \code{3} < \code{8} < \code{5} < \code{4} < \code{6} < \code{7}
	}
	\item{Treatment}{
	    a treatment factor with levels \code{1} to \code{4}.
	}
	\item{y}{
	    a numeric vector representing the response
	}
	\item{x}{
	    a numeric vector representing the covariate
	}
	\item{Grp}{
	    a factor with levels
	    \code{13} and 
	    \code{24} 
	}
    }
}
\details{
    These appear to be constructed data.
}
\source{
    Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
    R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
    (Data Set 5.4).
}
\examples{
data(BIB)
options(
  contrasts = c(unordered = "contr.SAS", ordered = "contr.poly"))
coplot(y ~ x | Block, data = BIB, show = FALSE)
fm1BIB <- lme(y ~ Treatment * x, data = BIB, random = ~ 1 | Block)
summary(fm1BIB)   # compare with Output 5.7, p. 188
VarCorr(fm1BIB)
anova(fm1BIB)     # strong evidence of different slopes
fm2BIB <- lme(y ~ Treatment + x : Grp, data = BIB,
              random = ~ 1 | Block)
summary(fm2BIB)   # compare with Output 5.9, p. 193
VarCorr(fm2BIB)
anova(fm2BIB)
}
\keyword{datasets}

\eof
\name{Bond}
\alias{Bond}
\non_function{}
\title{Strengths of metal bonds}
\description{
    The \code{Bond} data frame has 21 rows and 3 columns of data on the
    strength required to break metal bonds according to the metal and
    the ingot.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{pressure}{
	    a numeric vector of pressures required to break the bond
	}
	\item{Metal}{
	    a factor with levels \code{c}, \code{i} and \code{n}
	    indicating the metal involved (copper, iron or nickel).
	}
	\item{Ingot}{
	    an ordered factor indicating the ingot of the composition
	    material.
	}
    }
}
\source{
    Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
    R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
    (Data Set 1.2.4).

    Mendenhall, M., Wackerly, D. D. and Schaeffer, R. L. (1990),
    \emph{Mathematical Statistics}, Wadsworth (Exercise 13.36).
}
\examples{
data(Bond)
options(
  contrasts = c(unordered = "contr.SAS", ordered = "contr.poly"))
formula(Bond)                    # check the formula
fm1Bond <- lme( pressure ~ Metal, data = Bond, random = ~ 1 | Ingot)
summary( fm1Bond )               # compare with output 1.1 on p. 6
VarCorr( fm1Bond )               # variance component estimates 
anova( fm1Bond )
}
\keyword{datasets}

\eof
\name{Cultivation}
\alias{Cultivation}
\non_function{}
\title{Bacterial innoculation applied to grass cultivars}
\description{
    The \code{Cultivation} data frame has 24 rows and 4 columns of data
    from an experiment on the effect on dry weight yield of three
    bacterial inoculation treatments applied to two grass cultivars.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Block}{
	    a factor with levels \code{1} to \code{4}
	}
	\item{Cult}{
	    the cultivar factor with levels \code{a} and \code{b}
	}
	\item{Inoc}{
	    the innoculant factor with levels \code{con}, \code{dea} and
	    \code{liv}
	}
	\item{drywt}{
	    a numeric vector of dry weight yields
	}
    }
}
\source{
    Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
    R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
    (Data Set 2.2(a)).

    Littel, R. C., Freund, R. J., and Spector, P. C. (1991), \emph{SAS
	System for Linear Models, Third Ed.}, SAS Institute.
}
\examples{
data(Cultivation)
options(
  contrasts = c(unordered = "contr.SAS", ordered = "contr.poly"))
names( Cultivation )
formula( Cultivation )
fm1Cult <- lme( drywt ~ Inoc * Cult, data = Cultivation, 
                random = list( Block = ~ 1, Cult = ~ 1 ) )
summary( fm1Cult )   # compare with Output 2.10, page 58
VarCorr( fm1Cult )   
anova( fm1Cult )
fm2Cult <- update( fm1Cult, drywt ~ Inoc + Cult )
anova( fm2Cult )
fm3Cult <- update( fm1Cult, drywt ~ Inoc )
anova( fm3Cult )
summary( fm3Cult )
VarCorr( fm3Cult )
}
\keyword{datasets}

\eof
\name{Demand}
\alias{Demand}
\non_function{}
\title{Per-capita demand deposits by state and year}
\description{
    The \code{Demand} data frame has 77 rows and 8 columns of data on
    per-capita demand deposits by state and year.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{State}{
	    an ordered factor with levels
	    \code{WA} < \code{FL} < \code{CA} < \code{TX} < \code{IL} < \code{DC} < \code{NY}
	}
	\item{Year}{
	    an ordered factor with levels
	    \code{1949} < \dots{} < \code{1959}
	}
	\item{d}{
	    a numeric vector of per-capita demand deposits
	}
	\item{y}{
	    a numeric vector of permanent per-capita personal income
	}
	\item{rd}{
	    a numeric vector of service charges on demand deposits
	}
	\item{rt}{
	    a numeric vector of interest rates on time deposits
	}
	\item{rs}{
	    a numeric vector of interest rates on savings and loan
	    association shares.
	}
	\item{grp}{
	    a dummy factor with a single level.  This is used to
	    construct crossed random effects in \code{lme}.
	}
    }
}
\source{
    Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
    R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
    (Data Set 1.2.4).

    Feige, E. L. (1964), \emph{The Demand for Liquid Assets: A Temporal
	Cross-Sectional Analysis.}, Prentice Hall.
}
\examples{
data(Demand)
names( Demand )
formula( Demand )
# the "grp" factor is a dummy factor with only one level.
unique( Demand$grp )
# Crossed random-effects factors have to be created by pdIdent
#  applied to the indicator variables and joined by pdBlocked.
fm1Demand <-
  lme( log(d) ~ log(y) + log(rd) + log(rt) + log(rs), data = Demand,
  random = list(grp = pdBlocked(list(pdIdent(~ State - 1),
                                     pdIdent(~ Year - 1)))))
summary( fm1Demand )        # compare to output 3.13, p. 132
VarCorr( fm1Demand )
}
\keyword{datasets}

\eof
\name{Genetics}
\alias{Genetics}
\non_function{}
\title{Heritability data}
\description{
The \code{Genetics} data frame has 60 rows and 4 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Location}{
	    a factor with levels \code{1} to \code{4} 
	}
	\item{Block}{
	    a factor with levels \code{1} to \code{3}
	}
	\item{Family}{
	    a factor with levels \code{1} to \code{5}
	}
	\item{Yield}{
	    a numeric vector of crop yields
	}
    }
}
\source{
    Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
    R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
    (Data Set 4.5).
}
\examples{
data(Genetics)
options(
  contrasts = c(unordered = "contr.SAS", ordered = "contr.poly"))
formula( Genetics )
fm1Gen <- lme( Yield ~ 1, data = Genetics,
   random = list(Location = pdCompSymm(~ Family - 1), Block = ~ 1) )
summary( fm1Gen )
VarCorr( fm1Gen )      # compare with Output 4.18, p. 165
anova( fm1Gen )
}
\keyword{datasets}

\eof
\name{HR}
\alias{HR}
\non_function{}
\title{Heart rates of patients on different drug treatments}
\description{
    The \code{HR} data frame has 120 rows and 5 columns of the heart
    rates of patients under one of three possible drug treatments.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Patient}{
	    an ordered factor indicating the patient.
	}
	\item{Drug}{
	    the drug treatment - a factor with levels \code{a},
	    \code{b} and \code{p} where \code{p} represents the placebo.
	}
	\item{baseHR}{
	    the patient's base heart rate
	}
	\item{HR}{
	    the observed heart rate at different times in the experiment
	}
	\item{Time}{
	    the time of the observation
	}
    }
}
\source{
    Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
    R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
    (Data Set 3.5).
}
\examples{
options(
  contrasts = c(unordered = "contr.SAS", ordered = "contr.poly"))
data(HR)
coplot(HR ~ Time | Patient, type = "b", data = HR, show = FALSE)
formula(HR)
fm1HR <- lme( HR ~ Time * Drug + baseHR, data = HR,  # linear trend in time
   random = ~ Time | Patient)
summary( fm1HR )
VarCorr( fm1HR )
anova( fm1HR )
fm2HR <- update( fm1HR, weights = varPower(0.5) ) # use power-of-mean variance
summary( fm2HR )
VarCorr( fm1HR )
intervals( fm2HR )             # variance function does not seem significant
anova( fm1HR, fm2HR )         # confirm with likelihood ratio
fm3HR <- update( fm1HR, HR ~ Time + Drug + baseHR ) # remove interaction
anova( fm3HR )
summary( fm3HR )
VarCorr( fm3HR )
fm4HR <- update( fm3HR, HR ~ Time + baseHR )  # remove Drug term
anova( fm4HR )
summary( fm4HR )
VarCorr( fm4HR )
}
\keyword{datasets}

\eof
\name{IncBlk}
\alias{IncBlk}
\non_function{}
\title{An unbalanced incomplete block experiment}
\description{
    The \code{IncBlk} data frame has 24 rows and 4 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Block}{
	    an ordered factor giving the block
	}
	\item{Treatment}{
	    a factor with levels \code{1} to \code{4} 
	}
	\item{y}{
	    a numeric vector
	}
	\item{x}{
	    a numeric vector
	}
    }
}
\details{
    These data are probably constructed data.
}
\source{
    Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
    R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
    (Data Set 5.5).
}
\examples{
data(IncBlk)
str(IncBlk)
}
\keyword{datasets}

\eof
\name{Mississippi}
\alias{Mississippi}
\non_function{}
\title{Nitrogen concentrations in the Mississippi River}
\description{
The \code{Mississippi} data frame has 37 rows and 3 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{influent}{
	    an ordered factor with levels
	    \code{3} < \code{5} < \code{2} < \code{1} < \code{4} < \code{6}
	}
	\item{y}{
	    a numeric vector
	}
	\item{Type}{
	    a factor with levels
	    \code{1} 
	    \code{2} 
	    \code{3} 
	}
    }
}
\source{
    Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
    R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
    (Data Set 4.2).
}
\examples{
options(
  contrasts = c(unordered = "contr.SAS", ordered = "contr.poly"))
data(Mississippi)
formula( Mississippi )
#plot( Mississippi )
fm1Miss <- lme( y ~ 1, data = Mississippi, random = ~ 1 | influent )
summary( fm1Miss )        # compare with output 4.1, p. 142
fm1MLMiss <- update( fm1Miss, method = "ML" )
summary( fm1MLMiss )        # compare with output 4.2, p. 143
random.effects( fm1MLMiss ) # BLUP's of random effects on p. 144
random.effects( fm1MLMiss , aug = TRUE )   # including covariates
random.effects( fm1Miss )   # BLUP's of random effects on p. 142
intervals( fm1Miss )        # interval estimates of variance components
VarCorr( fm1Miss )          # compare to output 4.7, p. 148
fm2Miss <- lme( y ~ Type, data = Mississippi, random = ~ 1 | influent,
      method = "REML" )
summary( fm2Miss )         # compare to output 4.8 and 4.9, pp. 150-152
anova( fm2Miss )
}
\keyword{datasets}

\eof
\name{Multilocation}
\alias{Multilocation}
\non_function{}
\title{A multilocation trial}
\description{
  The \code{Multilocation} data frame has 108 rows and 7 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{obs}{
      a numeric vector
    }
    \item{Location}{
      an ordered factor with levels
      \code{B} < \code{D} < \code{E} < \code{I} < \code{G} <
      \code{A} < \code{C} < \code{F} < \code{H}
    }
    \item{Block}{
      a factor with levels \code{1} to \code{3} 
    }
    \item{Trt}{
      a factor with levels \code{1} to \code{4}
    }
    \item{Adj}{
      a numeric vector
    }
    \item{Fe}{
      a numeric vector
    }
    \item{Grp}{
      an ordered factor with levels
      \code{B/1} < \code{B/2} < \code{B/3} < \code{D/1} <
      \code{D/2} < \code{D/3} < \code{E/1} < \code{E/2} <
      \code{E/3} < \code{I/1} < \code{I/2} < \code{I/3} <
      \code{G/1} < \code{G/2} < \code{G/3} < \code{A/1} <
      \code{A/2} < \code{A/3} < \code{C/1} < \code{C/2} <
      \code{C/3} < \code{F/1} < \code{F/2} < \code{F/3} <
      \code{H/1} < \code{H/2} < \code{H/3}
    }
  }
}
\source{
  Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
  R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
  (Data Set 2.8.1).
}
\examples{
options(
  contrasts = c(unordered = "contr.SAS", ordered = "contr.poly"))
data(Multilocation)
formula( Multilocation )
names( Multilocation )
### Create a Block %in% Location factor
Multilocation$Grp <-
  getGroups( Multilocation, form = ~ Location/Block, level = 2 )
fm1Mult <- lme( Adj ~ Location * Trt, data = Multilocation, ~ 1 | Grp)
summary( fm1Mult )
VarCorr( fm1Mult )
anova( fm1Mult )
fm2Mult <- update( fm1Mult, Adj ~ Location + Trt )
fm3Mult <- update( fm1Mult, Adj ~ Location )
fm4Mult <- update( fm1Mult, Adj ~ Trt )
fm5Mult <- update( fm1Mult, Adj ~ 1 )
summary( fm2Mult )
VarCorr( fm2Mult )
anova( fm2Mult )
### Treating the location as a random effect
\dontrun{fm1MultR <- lme( Adj ~ Trt, data = Multilocation,
  random = list( Location = pdCompSymm( ~ Trt - 1 ), Block = ~ 1 ) )
summary( fm1MultR )
intervals( fm1MultR )
VarCorr( fm1MultR )
anova( fm1MultR )
}
\dontrun{
fm2MultR <-
  update( fm1MultR, random = list( Location = ~ Trt - 1, Block = ~ 1 ))
anova( fm1MultR, fm2MultR )
}
}
\keyword{datasets}

\eof
\name{PBIB}
\alias{PBIB}
\non_function{}
\title{A partially balanced incomplete block experiment}
\description{
    The \code{PBIB} data frame has 60 rows and 3 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{response}{
	    a numeric vector
	}
	\item{Treatment}{
	    a factor with levels \code{1} to \code{15} 
	}
	\item{Block}{
	    an ordered factor with levels \code{1} to \code{15} 
	}
    }
}
\details{
}
\source{
    Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
    R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
    (Data Set 1.5.1).
}
\examples{
options(
  contrasts = c(unordered = "contr.SAS", ordered = "contr.poly"))
data(PBIB)
formula( PBIB )
fm1PBIB <-
   lme( response ~ Treatment, data = PBIB, random = ~ 1 | Block)
summary( fm1PBIB )     # compare with output 1.7  pp. 24-25
VarCorr( fm1PBIB )
anova( fm1PBIB )
}
\keyword{datasets}

\eof
\name{SIMS}
\alias{SIMS}
\non_function{}
\title{Second International Mathematics Study data}
\description{
    The \code{SIMS} data frame has 3691 rows and 3 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Pretot}{
	    a numeric vector giving the student's pre-test total score
	}
	\item{Gain}{
	    a numeric vector giving gains from pre-test to the final test
	}
	\item{Class}{
	    an ordered factor giving the student's class
	}
    }
}
\details{
}
\source{
    Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
    R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
    (section 7.2.2)

    Kreft, I. G. G., De Leeuw, J. and Var Der Leeden, R. (1994),
    ``Review of five multilevel analysis programs: BMDP-5V, GENMOD, HLM,
    ML3, and VARCL'', \emph{American Statistician}, \bold{48}, 324--335.
}
\examples{
data(SIMS)
fm1SIMS <- lme(Gain ~ Pretot, data = SIMS, 
    random = ~ Pretot | Class, control = list(msVerbose = TRUE))
summary(fm1SIMS)              # compare to output 7.4, p. 262
VarCorr(fm1SIMS)
anova(fm1SIMS)
intervals( fm1SIMS )
}
\keyword{datasets}

\eof
\name{Semi2}
\alias{Semi2}
\non_function{}
\title{Oxide layer thicknesses on semiconductors}
\description{
    The \code{Semi2} data frame has 72 rows and 5 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Source}{
	    a factor with levels \code{1} and \code{2} 
	}
	\item{Lot}{
	    a factor with levels \code{1} to \code{8}
	}
	\item{Wafer}{
	    a factor with levels \code{1} to \code{3}
	}
	\item{Site}{
	    a factor with levels \code{1} to \code{3}
	}
	\item{Thickness}{
	    a numeric vector
	}
    }
}
\details{

}
\source{
    Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
    R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
    (Data Set 4.4).
}
\examples{
options(
  contrasts = c(unordered = "contr.SAS", ordered = "contr.poly"))
data(Semi2)
formula(Semi2)
fm1Semi2 <- lme( Thickness ~ 1, data = Semi2,
   random = ~ 1 | Lot/Wafer )
summary( fm1Semi2 )       # compare with output 4.13, p. 156
VarCorr( fm1Semi2 )
anova( fm1Semi2 )
fm2Semi2 <- update( fm1Semi2, Thickness ~ Source )
summary( fm2Semi2 )       # compare with output 4.15, p. 159
VarCorr( fm2Semi2 )
fm3Semi2 <- update( fm2Semi2, 
   random = list(Lot = pdDiag( ~ Source - 1 ), Wafer = ~ 1 ) )
summary( fm3Semi2 )       # compare with output 4.17, p. 163
VarCorr( fm3Semi2 )
}
\keyword{datasets}

\eof
\name{Semiconductor}
\alias{Semiconductor}
\non_function{}
\title{Semiconductor split-plot experiment}
\description{
    The \code{Semiconductor} data frame has 48 rows and 5 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{resistance}{
	    a numeric vector
	}
	\item{ET}{
	    a factor with levels \code{1} to \code{4} representing etch time.
	}
	\item{Wafer}{
	    a factor with levels \code{1} to \code{3} 
	}
	\item{position}{
	    a factor with levels \code{1} to \code{4} 
	}
	\item{Grp}{
	    an ordered factor with levels
	    \code{1/1} < \code{1/2} < \code{1/3} < \code{2/1} < \code{2/2} < \code{2/3} < \code{3/1} < \code{3/2} < \code{3/3} < \code{4/1} < \code{4/2} < \code{4/3}
	}
    }
}
\details{
}
\source{
    Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
    R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
    (Data Set 2.2(b)).

}
\examples{
options(
  contrasts = c(unordered = "contr.SAS", ordered = "contr.poly"))
data(Semiconductor)
formula( Semiconductor )
names( Semiconductor )
fm1Semi <- lme( resistance ~ ET * position,
                 data = Semiconductor,
                 random = ~ 1 | Grp)
summary( fm1Semi )
VarCorr( fm1Semi )
anova( fm1Semi )
fm2Semi <- update( fm1Semi, resistance ~ ET + position )
anova(fm2Semi)
}
\keyword{datasets}

\eof
\name{TeachingI}
\alias{TeachingI}
\non_function{}
\title{Teaching Methods I}
\description{
    The \code{TeachingI} data frame has 96 rows and 7 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Method}{
	    a factor with levels \code{1} to \code{3}
	}
	\item{Teacher}{
	    a factor with levels \code{1} to \code{4}
	}
	\item{Gender}{
	    a factor with levels \code{f} and \code{m} 
	}
	\item{Student}{
	    a factor with levels \code{1} to \code{4}
	}
	\item{score}{
	    a numeric vector
	}
	\item{Experience}{
	    a numeric vector
	}
	\item{uTeacher}{
	    an ordered factor with levels
	}
    }
}
\details{
}
\source{
    Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
    R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
    (Data Set 5.6).
}
\examples{
options(
  contrasts = c(unordered = "contr.SAS", ordered = "contr.poly"))
data(TeachingI)
}
\keyword{datasets}

\eof
\name{TeachingII}
\alias{TeachingII}
\non_function{}
\title{Teaching Methods II}
\description{
    The \code{TeachingII} data frame has 96 rows and 6 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Method}{
	    a factor with levels \code{1} to \code{3} 
	}
	\item{Teacher}{
	    a factor with levels \code{1} to \code{4}
	}
	\item{Gender}{
	    a factor with levels \code{f} and \code{m} 
	}
	\item{IQ}{
	    a numeric vector
	}
	\item{score}{
	    a numeric vector
	}
	\item{uTeacher}{
	    an ordered factor with levels
	}
    }
}
\details{

}
\source{
    Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
    R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
    (Data Set 5.7).
}
\examples{
options(
  contrasts = c(unordered = "contr.SAS", ordered = "contr.poly"))
data(TeachingII)
}
\keyword{datasets}

\eof
\name{WWheat}
\alias{WWheat}
\non_function{}
\title{Winter wheat}
\description{
    The \code{WWheat} data frame has 60 rows and 3 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Variety}{
	    an ordered factor with 10 levels
	}
	\item{Yield}{
	    a numeric vector of yields
	}
	\item{Moisture}{
	    a numeric vector of soil moisture contents
	}
    }
}
\details{
}
\source{
    Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
    R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
    (Data Set 7.2).
}
\examples{
options(
  contrasts = c(unordered = "contr.SAS", ordered = "contr.poly"))
data(WWheat)
}
\keyword{datasets}

\eof
\name{WaferTypes}
\alias{WaferTypes}
\non_function{}
\title{Data on different types of silicon wafers}
\description{
    The \code{WaferTypes} data frame has 144 rows and 8 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Group}{
	    a factor with levels \code{1} to \code{4}
	}
	\item{Temperature}{
	    an ordered factor with levels
	    \code{900} < \code{1000} < \code{1100}
	}
	\item{Type}{
	    a factor with levels \code{A} and \code{B} 
	}
	\item{Wafer}{
	    a numeric vector
	}
	\item{Site}{
	    a numeric vector
	}
	\item{delta}{
	    a numeric vector
	}
	\item{Thick}{
	    a numeric vector
	}
	\item{uWafer}{
	    an ordered factor giving a unique code to each group,
	    temperature, type and wafer combination.
	}
    }
}
\details{

}
\source{
    Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
    R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
    (Data Set 5.8).
}
\examples{
options(
  contrasts = c(unordered = "contr.SAS", ordered = "contr.poly"))
data(WaferTypes)
str(WaferTypes)
}
\keyword{datasets}

\eof
\name{Weights}
\alias{Weights}
\non_function{}
\title{Data from a weight-lifting program}
\description{
    The \code{Weights} data frame has 399 rows and 5 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{strength}{
      a numeric vector
    }
    \item{Subject}{
      a factor with levels \code{1} to \code{21}
    }
    \item{Program}{
      a factor with levels
      \code{CONT} (continuous repetitions and weights),
      \code{RI} (repetitions increasing) and
      \code{WI} (weights increasing)
    }
    \item{Subj}{
      an ordered factor indicating the subject on which the
      measurement is made
    }
    \item{Time}{
      a numeric vector indicating the time of the measurement
    }
  }
}
\source{
  Littel, R. C., Milliken, G. A., Stroup, W. W., and Wolfinger,
  R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute
  (Data Set 3.2(a)).
}
\examples{
options(
  contrasts = c(unordered = "contr.SAS", ordered = "contr.poly"))
data(Weights)
fm1Weight <- lme( strength ~ Program * Time,
                  data = Weights, random = ~ 1 | Subj)
summary( fm1Weight )               # compare with output 3.1, p. 91
VarCorr( fm1Weight )
anova( fm1Weight )
fm2Weight <- update( fm1Weight, random = ~ Time | Subj )
anova( fm1Weight, fm2Weight )
summary( fm2Weight )
VarCorr( fm2Weight )
intervals( fm2Weight )
\dontrun{
fm3Weight <- update( fm2Weight, correlation = corAR1())
anova( fm2Weight, fm3Weight )
fm4Weight <- update( fm3Weight, strength ~ Program * (Time + I(Time^2)),
                    random = ~Time|Subj)
summary( fm4Weight )
VarCorr( fm4Weight )
anova( fm4Weight )
intervals( fm4Weight )
}
}
\keyword{datasets}

\eof
